@@ -41,7 +41,8 @@ void init_debug (void)
 		debug_level = true;
 }
 
-static void vdebug (const char *message, va_list args)
+static void ATTRIBUTE_FORMAT_PRINTF (1, 0) vdebug (const char *message,
+						   va_list args)
 {
 	if (debug_level)
 		vfprintf (stderr, message, args);
